@@ -170,6 +170,15 @@ rescale_reps.svyrep.design <- function(x, tau = "auto", min_wgt = 0.01, digits =
 #' if all of the adjustment factors are nonnegative, then \code{tau} is set equal to 1;
 #' otherwise, \code{tau} is set to the smallest value needed to rescale
 #' the adjustment factors such that they are all at least \code{0.01}.
+#' @param exact_vcov If \code{exact_vcov=TRUE}, the replicate factors will be generated
+#' such that their variance-covariance matrix exactly matches the target variance estimator's
+#' quadratic form (within numeric precision).
+#' This is desirable as it causes variance estimates for totals to closely match
+#' the values from the target variance estimator.
+#' This requires that \code{num_replicates} exceeds the rank of \code{Sigma}.
+#' The replicate factors are generated by applying PCA-whitening to a collection of draws
+#' from a multivariate Normal distribution, then applying a coloring transformation
+#' to the whitened collection of draws.
 #'
 #' @section Statistical Details:
 #' Let \eqn{v( \hat{T_y})} be the textbook variance estimator for an estimated population total \eqn{\hat{T}_y} of some variable \eqn{y}.
@@ -319,18 +328,51 @@ rescale_reps.svyrep.design <- function(x, tau = "auto", min_wgt = 0.01, digits =
 #' svytotal(x = ~ Bush + Kerry,
 #'          design = election_pps_ht_design)
 #' }
-make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
+make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto", exact_vcov = FALSE) {
 
   n <- nrow(Sigma)
 
   # Generate replicate factors by simulating from a multivariate normal distribution
-  replicate_factors <- t(
-    mvtnorm::rmvnorm(n = num_replicates,
-                     mean = rep(1, times = n),
-                     sigma = Sigma,
-                     checkSymmetry = TRUE,
-                     method = "eigen")
-  )
+  if (!exact_vcov) {
+    replicate_factors <- t(
+      mvtnorm::rmvnorm(n = num_replicates,
+                       mean = rep(1, times = n),
+                       sigma = Sigma,
+                       checkSymmetry = TRUE,
+                       method = "eigen")
+    )
+  }
+  if (exact_vcov) {
+    qr_rank <- qr(Sigma)$rank
+    if (num_replicates <= qr_rank) {
+      err_msg <- paste(
+        "`exact_vcov=TRUE` only works if `num_replicates` exceeds the rank of `Sigma`,",
+        sprintf("which is %s", qr_rank)
+      )
+      stop(err_msg)
+    }
+    # Draw from standard multivariate normal
+    draws <- mvtnorm::rmvnorm(n = num_replicates,
+                              mean = rep(0, times = n),
+                              sigma = diag(n),
+                              checkSymmetry = FALSE,
+                              method = "eigen")
+    # Whiten the draws
+    draws <- scale(draws, center = TRUE, scale = FALSE)
+    draws <- draws %*% svd(draws, nu = 0, nv = n)$v
+    draws <- scale(draws, FALSE, TRUE)
+    # Color the draws
+    replicate_factors <- with(svd(Sigma, nu = 0, nv = n), {
+      (v %*% diag(sqrt(pmax(d, 0)), n)) %*% t(draws)
+    })
+    # Adjust the scale of the replicates,
+    # since the generalized bootstrap uses the scale (1/B),
+    # but the coloring process gives the exact result only for scale (1/(B-1))
+    scale_adjustment <- sqrt((num_replicates)/(num_replicates-1))
+    replicate_factors <- replicate_factors * scale_adjustment
+    # Make sure that draws have the exact specified mean
+    replicate_factors <- rep(1, times = n) + replicate_factors
+  }
 
   # (Potentially) rescale to avoid negative weights
   rescaled_replicate_factors <- rescale_reps(
@@ -351,7 +393,7 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
   return(rescaled_replicate_factors)
 }
 
-#' @title Convert a survey design object to a generalized boostrap replicate design
+#' @title Convert a survey design object to a generalized bootstrap replicate design
 #' @description Converts a survey design object to a replicate design object
 #' with replicate weights formed using the generalized bootstrap method.
 #' The generalized survey bootstrap is a method for forming bootstrap replicate weights
@@ -375,6 +417,12 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
 #'   based on estimating the variance of cluster totals within strata at each stage.}
 #'   \item{\strong{"Ultimate Cluster"}: }{The usual variance estimator based on estimating
 #'   the variance of first-stage cluster totals within first-stage strata.}
+#'   \item{\strong{"Deville-1"}: }{A variance estimator for unequal-probability
+#'   sampling without replacement, described in Matei and Tillé (2005)
+#'   as "Deville 1".}
+#'   \item{\strong{"Deville-2"}: }{A variance estimator for unequal-probability
+#'   sampling without replacement, described in Matei and Tillé (2005)
+#'   as "Deville 2".}
 #'   \item{\strong{"SD1"}: }{The non-circular successive-differences variance estimator described by Ash (2014),
 #'   sometimes used for variance estimation for systematic sampling.}
 #'   \item{\strong{"SD2"}: }{The circular successive-differences variance estimator described by Ash (2014).
@@ -390,6 +438,12 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
 #' if all of the adjustment factors are nonnegative, then \code{tau} is set equal to 1;
 #' otherwise, \code{tau} is set to the smallest value needed to rescale
 #' the adjustment factors such that they are all at least \code{0.01}.
+#' @param exact_vcov If \code{exact_vcov=TRUE}, the replicate factors will be generated
+#' such that variance estimates for totals exactly match the results from the target variance estimator.
+#' This requires that \code{num_replicates} exceeds the rank of \code{Sigma}.
+#' The replicate factors are generated by applying PCA-whitening to a collection of draws
+#' from a multivariate Normal distribution, then applying a coloring transformation
+#' to the whitened collection of draws.
 #' @param psd_option Either \code{"warn"} (the default) or \code{"error"}.
 #' This option specifies what will happen if the target variance estimator
 #' has a quadratic form matrix which is not positive semidefinite. This
@@ -410,7 +464,7 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
 #' If \code{FALSE}, compute variances from sums of squares around the mean estimate from the replicate weights.
 #' @return
 #' A replicate design object, with class \code{svyrep.design}, which can be used with the usual functions,
-#' such as \code{svymean()} or \code{svyglm()}. \cr \cr
+#' such as \code{svymean()} or \code{svyglm()}. \cr
 #' Use \code{weights(..., type = 'analysis')} to extract the matrix of replicate weights. \cr
 #' Use \code{as_data_frame_with_weights()} to convert the design object to a data frame with columns
 #' for the full-sample and replicate weights.
@@ -476,69 +530,7 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
 #' }
 #' When sharing a dataset that uses rescaled weights from a generalized survey bootstrap, the documentation for the dataset should instruct the user to use replication scale factor \eqn{\frac{\tau^2}{B}} rather than \eqn{\frac{1}{B}} when estimating sampling variances.
 #'
-#' @section Variance Estimators:
-#' The \strong{Horvitz-Thompson} variance estimator:
-#' \deqn{
-#'   v(\hat{Y}) = \sum_{i \in s}\sum_{j \in s} (1 - \frac{\pi_i \pi_j}{\pi_{ij}}) \frac{y_i}{\pi_i} \frac{y_j}{\pi_j}
-#' }
-#' The \strong{Poisson Horvitz-Thompson} variance estimator
-#' is simply the Horvitz-Thompson variance estimator, but
-#' where \eqn{\pi_{ij}=\pi_i \times \pi_j}, which is the case for Poisson sampling. \cr \cr
-#' The \strong{Yates-Grundy} variance estimator:
-#' \deqn{
-#'   v(\hat{Y}) = -\frac{1}{2}\sum_{i \in s}\sum_{j \in s} (1 - \frac{\pi_i \pi_j}{\pi_{ij}}) (\frac{y_i}{\pi_i} - \frac{y_j}{\pi_j})^2
-#' }
-#' The \strong{Stratified Multistage SRS} variance estimator is the recursive variance estimator
-#' proposed by Bellhouse (1985) and used in the 'survey' package's function \link[survey]{svyrecvar}.
-#' The estimator can be used for any number of sampling stages. For illustration, we describe its use
-#' for two sampling stages.
-#' \deqn{
-#'   v(\hat{Y}) = \hat{V}_1 + \hat{V}_2
-#' }
-#' where
-#' \deqn{
-#'   \hat{V}_1 = \sum_{h=1}^{H} (1 - \frac{n_h}{N_h})\frac{n_h}{n_h - 1} \sum_{i=1}^{n_h} (y_{hi.} - \bar{y}_{hi.})^2
-#' }
-#' and
-#' \deqn{
-#'   \hat{V}_2 = \sum_{h=1}^{H} \frac{n_h}{N_h} \sum_{i=1}^{n_h}v_{hi}(y_{hi.})
-#' }
-#' where \eqn{n_h} is the number of sampled clusters in stratum \eqn{h},
-#' \eqn{N_h} is the number of population clusters in stratum \eqn{h},
-#' \eqn{y_{hi.}} is the weighted cluster total in cluster \eqn{i} of stratum \eqn{h},
-#' \eqn{\bar{y}_{hi.}} is the mean weighted cluster total of stratum \eqn{h},
-#' (\eqn{\bar{y}_{hi.} = \frac{1}{n_h}\sum_{i=1}^{n_h}y_{hi.}}), and
-#' \eqn{v_{hi}(y_{hi.})} is the estimated sampling variance of \eqn{y_{hi.}}.
-#' \cr \cr
-#' The \strong{Ultimate Cluster} variance estimator is simply the stratified multistage SRS
-#' variance estimator, but ignoring variances from later stages of sampling.
-#' \deqn{
-#'   v(\hat{Y}) = \hat{V}_1
-#' }
-#' This is the variance estimator used in the 'survey' package when the user specifies
-#' \code{option(survey.ultimate.cluster = TRUE)} or uses \code{svyrecvar(..., one.stage = TRUE)}.
-#' When the first-stage sampling fractions are small, analysts often omit the finite population corrections \eqn{(1-\frac{n_h}{N_h})}
-#' when using the ultimate cluster estimator.
-#' \cr \cr
-#' The \strong{SD1} and \strong{SD2} variance estimators are "successive difference"
-#' estimators sometimes used for systematic sampling designs.
-#' Ash (2014) describes each estimator as follows:
-#' \deqn{
-#'   \hat{v}_{S D 1}(\hat{Y}) = \left(1-\frac{n}{N}\right) \frac{n}{2(n-1)} \sum_{k=2}^n\left(\breve{y}_k-\breve{y}_{k-1}\right)^2
-#' }
-#' \deqn{
-#'   \hat{v}_{S D 2}(\hat{Y}) = \left(1-\frac{n}{N}\right) \frac{1}{2}\left[\sum_{k=2}^n\left(\breve{y}_k-\breve{y}_{k-1}\right)^2+\left(\breve{y}_n-\breve{y}_1\right)^2\right]
-#' }
-#' where \eqn{\breve{y}_k = y_k/\pi_k} is the weighted value of unit \eqn{k}
-#' with selection probability \eqn{\pi_k}. The SD1 estimator is recommended by Wolter (1984).
-#' The SD2 estimator is the basis of the successive difference replication estimator commonly
-#' used for systematic sampling designs. See Ash (2014) for details.
-#' \cr \cr
-#' For multistage samples, SD1 and SD2 are applied to the clusters at each stage, separately by stratum.
-#' For later stages of sampling, the variance estimate from a stratum is multiplied by the product
-#' of sampling fractions from earlier stages of sampling. For example, at a third stage of sampling,
-#' the variance estimate from a third-stage stratum is multiplied by \eqn{\frac{n_1}{N_1}\frac{n_2}{N_2}},
-#' which is the product of sampling fractions from the first-stage stratum and second-stage stratum.
+#' @inheritSection make_quad_form_matrix Variance Estimators
 #' @section Two-Phase Designs:
 #' For a two-phase design, \code{variance_estimator} should be a list of variance estimators' names,
 #' with two elements, such as \code{list('Ultimate Cluster', 'Poisson Horvitz-Thompson')}.
@@ -569,7 +561,11 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
 #' - Dippo, Cathryn, Robert Fay, and David Morganstein. 1984. “Computing Variances from Complex Samples with Replicate Weights.” In, 489–94. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1984_094.pdf.
 #' \cr \cr
 #' - Fay, Robert. 1984. “Some Properties of Estimates of Variance Based on Replication Methods.” In, 495–500. Alexandria, VA: American Statistical Association. http://www.asasrms.org/Proceedings/papers/1984_095.pdf.
-#' \cr
+#' \cr \cr
+#' - Matei, Alina, and Yves Tillé. (2005).
+#' “\emph{Evaluation of Variance Approximations and Estimators
+#' in Maximum Entropy Sampling with Unequal Probability and Fixed Sample Size.}”
+#' \strong{Journal of Official Statistics}, 21(4):543–70.
 #'
 #' @export
 #'
@@ -664,17 +660,17 @@ make_gen_boot_factors <- function(Sigma, num_replicates, tau = "auto") {
 #'
 #' }
 as_gen_boot_design <- function(design, variance_estimator = NULL,
-                               replicates = 500, tau = "auto",
-                               psd_option = "warn",
-                               mse = getOption("survey.replicates.mse"),
-                               compress = TRUE) {
+                                replicates = 500, tau = "auto", exact_vcov = FALSE,
+                                psd_option = "warn",
+                                mse = getOption("survey.replicates.mse"),
+                                compress = TRUE) {
   UseMethod("as_gen_boot_design", design)
 }
 
 #' @export
 as_gen_boot_design.twophase2 <- function(design, variance_estimator = NULL,
                                          replicates = 500, tau = "auto",
-                                         psd_option = "warn",
+                                         exact_vcov = FALSE, psd_option = "warn",
                                          mse = getOption("survey.replicates.mse"),
                                          compress = TRUE) {
 
@@ -708,7 +704,8 @@ as_gen_boot_design.twophase2 <- function(design, variance_estimator = NULL,
   adjustment_factors <- make_gen_boot_factors(
     Sigma = Sigma,
     num_replicates = replicates,
-    tau = tau
+    tau = tau,
+    exact_vcov = exact_vcov
   )
 
   rep_design <- survey::svrepdesign(
@@ -724,6 +721,12 @@ as_gen_boot_design.twophase2 <- function(design, variance_estimator = NULL,
 
   rep_design$tau <- attr(adjustment_factors, 'tau')
 
+  if (inherits(design, 'tbl_svy') && ('package:srvyr' %in% search())) {
+    rep_design <- srvyr::as_survey_rep(
+      rep_design
+    )
+  }
+
   rep_design$call <- sys.call(which = -1)
 
   return(rep_design)
@@ -731,8 +734,8 @@ as_gen_boot_design.twophase2 <- function(design, variance_estimator = NULL,
 
 #' @export
 as_gen_boot_design.survey.design <- function(design, variance_estimator = NULL,
-                                             replicates = 500, tau = "auto",
-                                             psd_option = "warn",
+                                             replicates = 500, tau = "auto", exact_vcov = FALSE,
+                                             psd_option = 'warn',
                                              mse = getOption("survey.replicates.mse"),
                                              compress = TRUE) {
 
@@ -760,7 +763,8 @@ as_gen_boot_design.survey.design <- function(design, variance_estimator = NULL,
   adjustment_factors <- make_gen_boot_factors(
     Sigma = Sigma,
     num_replicates = replicates,
-    tau = tau
+    tau = tau,
+    exact_vcov = exact_vcov
   )
 
   rep_design <- survey::svrepdesign(
@@ -776,6 +780,12 @@ as_gen_boot_design.survey.design <- function(design, variance_estimator = NULL,
 
   rep_design$tau <- attr(adjustment_factors, 'tau')
 
+  if (inherits(design, 'tbl_svy') && ('package:srvyr' %in% search())) {
+    rep_design <- srvyr::as_survey_rep(
+      rep_design
+    )
+  }
+
   rep_design$call <- sys.call(which = -1)
 
   return(rep_design)
