@@ -20,18 +20,31 @@
 #'   \item{\strong{"Stratified Multistage SRS"}: }{The usual stratified multistage variance estimator
 #'   based on estimating the variance of cluster totals within strata at each stage.
 #'   If this option is used, then it is necessary to also use the arguments
-#'   \code{strata_ids}, \code{cluster_ids}, \code{strata_samp_sizes}, and \code{strata_pop_sizes}.}
+#'   \code{strata_ids}, \code{cluster_ids}, \code{strata_pop_sizes}, and \code{strata_pop_sizes}.}
 #'   \item{\strong{"Ultimate Cluster"}: }{The usual variance estimator based on estimating
 #'   the variance of first-stage cluster totals within first-stage strata.
 #'   If this option is used, then it is necessary to also use the arguments
-#'   \code{strata_ids}, \code{cluster_ids}, \code{strata_samp_sizes}.
+#'   \code{strata_ids}, \code{cluster_ids}, \code{strata_pop_sizes}.
 #'   Optionally, to use finite population correction factors, one can also use the argument \code{strata_pop_sizes}.}
+#'   \item{\strong{"Deville-1"}: }{A variance estimator for unequal-probability
+#'   sampling without replacement, described in Matei and Tillé (2005)
+#'   as "Deville 1". If this option is used, then it is necessary to also use the arguments
+#'   \code{strata_ids}, \code{cluster_ids}, and \code{probs}.}
+#'   \item{\strong{"Deville-2"}: }{A variance estimator for unequal-probability
+#'   sampling without replacement, described in Matei and Tillé (2005)
+#'   as "Deville 2". If this option is used, then it is necessary to also use the arguments
+#'   \code{strata_ids}, \code{cluster_ids}, and \code{probs}.}
 #'   \item{\strong{"SD1"}: }{The non-circular successive-differences variance estimator described by Ash (2014),
 #'   sometimes used for variance estimation for systematic sampling.}
 #'   \item{\strong{"SD2"}: }{The circular successive-differences variance estimator described by Ash (2014).
 #'   This estimator is the basis of the "successive-differences replication" estimator commonly used
 #'   for variance estimation for systematic sampling.}
 #' }
+#' @param probs Required if \code{variance_estimator} equals \code{"Deville-1"} or \code{"Deville-2"}.
+#' This should be a matrix or data frame of sampling probabilities.
+#' If there are multiple stages of sampling,
+#' then \code{probs} can have multiple columns,
+#' with one column for each level of sampling to be accounted for by the variance estimator.
 #' @param joint_probs Only used if \code{variance_estimator = "Horvitz-Thompson"} or \code{variance_estimator = "Yates-Grundy"}.
 #' This should be a matrix of joint inclusion probabilities.
 #' Element \code{[i,i]} of the matrix is the first-order inclusion probability of unit \code{i},
@@ -55,15 +68,16 @@
 #' @section Arguments required for each variance estimator:
 #' Below are the arguments that are required or optional for each variance estimator.
 #'
-#' | variance_estimator       | joint_probs | cluster_ids | strata_ids  | strata_pop_sizes | sort_order |
-#' | ------------------------ | -----------:| -----------:| -----------:| ----------------:|-----------:|
-#' | Yates-Grundy             | Required    |             |             |                  |            |
-#' | Horvitz-Thompson         | Required    |             |             |                  |            |
-#' | Stratified Multistage SRS|             | Required    | Required    | Required         |            |
-#' | Ultimate Cluster         |             | Required    | Required    | Optional         |            |
-#' | SD1                      |             | Required    | Optional    | Optional         | Required   |
-#' | SD2                      |             | Required    | Optional    | Optional         | Required   |
-#'
+#' | variance_estimator       | probs      | joint_probs | cluster_ids | strata_ids  | strata_pop_sizes | sort_order |
+#' | ------------------------ |-----------:| -----------:| -----------:| -----------:| ----------------:|-----------:|
+#' | Stratified Multistage SRS|            |             | Required    | Required    | Required         |            |
+#' | Ultimate Cluster         |            |             | Required    | Required    | Optional         |            |
+#' | SD1                      |            |             | Required    | Optional    | Optional         | Required   |
+#' | SD2                      |            |             | Required    | Optional    | Optional         | Required   |
+#' | Deville-1                | Required   |             | Required    | Optional    |                  |            |
+#' | Deville-2                | Required   |             | Required    | Optional    |                  |            |
+#' | Yates-Grundy             |            | Required    |             |             |                  |            |
+#' | Horvitz-Thompson         |            | Required    |             |             |                  |            |
 #' @section Variance Estimators:
 #' The \strong{Horvitz-Thompson} variance estimator:
 #' \deqn{
@@ -73,6 +87,10 @@
 #' \deqn{
 #'   v(\hat{Y}) = -\frac{1}{2}\sum_{i \in s}\sum_{j \in s} (1 - \frac{\pi_i \pi_j}{\pi_{ij}}) (\frac{y_i}{\pi_i} - \frac{y_j}{\pi_j})^2
 #' }
+#' The \strong{Poisson Horvitz-Thompson} variance estimator
+#' is simply the Horvitz-Thompson variance estimator, but
+#' where \eqn{\pi_{ij}=\pi_i \times \pi_j}, which is the case for Poisson sampling.
+#' \cr \cr
 #' The \strong{Stratified Multistage SRS} variance estimator is the recursive variance estimator
 #' proposed by Bellhouse (1985) and used in the 'survey' package's function \link[survey]{svyrecvar}.
 #' The estimator can be used for any number of sampling stages. For illustration, we describe its use
@@ -124,12 +142,50 @@
 #' of sampling fractions from earlier stages of sampling. For example, at a third stage of sampling,
 #' the variance estimate from a third-stage stratum is multiplied by \eqn{\frac{n_1}{N_1}\frac{n_2}{N_2}},
 #' which is the product of sampling fractions from the first-stage stratum and second-stage stratum.
+#' \cr \cr
+#' The \strong{"Deville-1"} and \strong{"Deville-2"} variance estimators
+#' are clearly described in Matei and Tillé (2005),
+#' and are intended for designs that use
+#' fixed-size, unequal-probability random sampling without replacement.
+#' These variance estimators have been shown to be effective
+#' for designs that use a fixed sample size with a high-entropy sampling method.
+#' This includes most PPSWOR sampling methods,
+#' but unequal-probability systematic sampling is an important exception.
+#'
+#' These variance estimators take the following form:
+#' \deqn{
+#' \hat{v}(\hat{Y}) = \sum_{i=1}^{n} c_i (\breve{y}_i - \frac{1}{\sum_{i=k}^{n}c_k}\sum_{k=1}^{n}c_k \breve{y}_k)^2
+#' }
+#' where \eqn{\breve{y}_i = y_i/\pi_i} is the weighted value of the the variable of interest,
+#' and \eqn{c_i} depend on the method used:
+#' \itemize{
+#'   \item{\strong{"Deville-1"}: }{
+#'     \deqn{c_i=\left(1-\pi_i\right) \frac{n}{n-1}}}
+#'   \item{\strong{"Deville-2"}: }{
+#'     \deqn{c_i = (1-\pi_i) \left[1 - \sum_{k=1}^{n} \left(\frac{1-\pi_k}{\sum_{k=1}^{n}(1-\pi_k)}\right)^2 \right]^{-1}}}
+#' }
+#' In the case of simple random sampling without replacement (SRSWOR),
+#' these estimators are both identical to the usual stratified multistage SRS estimator
+#' (which is itself a special case of the Horvitz-Thompson estimator).
+#'
+#' For multistage samples, "Deville-1" and "Deville-2" are applied to the clusters at each stage, separately by stratum.
+#' For later stages of sampling, the variance estimate from a stratum is multiplied by the product
+#' of sampling probabilities from earlier stages of sampling. For example, at a third stage of sampling,
+#' the variance estimate from a third-stage stratum is multiplied by \eqn{\pi_1 \times \pi_{(2 | 1)}},
+#' where \eqn{\pi_1} is the sampling probability of the first-stage unit
+#' and \eqn{\pi_{(2|1)}} is the sampling probability of the second-stage unit
+#' within the first-stage unit.
 #' @references
 #' Ash, S. (2014). "\emph{Using successive difference replication for estimating variances}."
 #' \strong{Survey Methodology}, Statistics Canada, 40(1), 47–59.
 #'
 #' Bellhouse, D.R. (1985). "\emph{Computing Methods for Variance Estimation in Complex Surveys}."
 #' \strong{Journal of Official Statistics}, Vol.1, No.3.
+#'
+#' Matei, Alina, and Yves Tillé. (2005).
+#' “\emph{Evaluation of Variance Approximations and Estimators
+#' in Maximum Entropy Sampling with Unequal Probability and Fixed Sample Size.}”
+#' \strong{Journal of Official Statistics}, 21(4):543–70.
 #' @md
 #' @return The matrix of the quadratic form representing the variance estimator.
 #' @export
@@ -173,6 +229,7 @@
 #'   wtd_y <- as.matrix(weights(multistage_srswor_design) * mu284$y1)
 #'   t(wtd_y) %*% multistage_srs_quad_form %*% wtd_y
 #'
+#'   ##_ Compare against result from 'survey' package
 #'   svytotal(x = ~ y1, design = multistage_srswor_design) |> vcov()
 #'
 #' # Example 3: Successive-differences estimator ----
@@ -191,9 +248,23 @@
 #'                       library_stsys_sample$SAMPLING_PROB)
 #'   wtd_y[is.na(wtd_y)] <- 0
 #'
-#' t(wtd_y) %*% sd1_quad_form %*% wtd_y
+#'   t(wtd_y) %*% sd1_quad_form %*% wtd_y
+#'
+#' # Example 4: Deville estimators ----
+#'
+#'  data('library_multistage_sample', package = 'svrep')
+#'
+#'  deville_quad_form <- make_quad_form_matrix(
+#'      variance_estimator = 'Deville-1',
+#'      cluster_ids = library_multistage_sample[,c("PSU_ID", "SSU_ID")],
+#'      strata_ids = cbind(rep(1, times = nrow(library_multistage_sample)),
+#'                         library_multistage_sample$PSU_ID),
+#'      probs = library_multistage_sample[,c("PSU_SAMPLING_PROB",
+#'                                           "SSU_SAMPLING_PROB")]
+#'  )
 #' }
 make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
+                                  probs = NULL,
                                   joint_probs = NULL,
                                   cluster_ids = NULL,
                                   strata_ids = NULL,
@@ -203,7 +274,7 @@ make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
   accepted_variance_estimators <- c(
     "Yates-Grundy", "Horvitz-Thompson",
     "Ultimate Cluster", "Stratified Multistage SRS",
-    "SD1", "SD2"
+    "SD1", "SD2", "Deville-1", "Deville-2"
   )
 
   if (length(variance_estimator) > 1) {
@@ -229,10 +300,10 @@ make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
 
   # Check inputs and assemble all necessary information
   # for estimators of stratified/clustered designs
-  if (variance_estimator %in% c("Stratified Multistage SRS", "Ultimate Cluster", "SD1", "SD2")) {
+  if (variance_estimator %in% c("Stratified Multistage SRS", "Ultimate Cluster", "SD1", "SD2", "Deville-1", "Deville-2")) {
 
     # Ensure the minimal set of inputs is supplied
-    if (variance_estimator %in% c("Stratified Multistage SRS", "Ultimate Cluster")) {
+    if (variance_estimator %in% c("Stratified Multistage SRS", "Ultimate Cluster", "Deville-1", "Deville-2")) {
       if (is.null(cluster_ids) || is.null(strata_ids)) {
         sprintf(
           "For `variance_estimator='%s'`, must supply a matrix or data frame to both `strata_ids` and `cluster_ids`",
@@ -240,18 +311,29 @@ make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
         ) |> stop()
       }
     }
+    if (variance_estimator %in% c("Deville-1", "Deville-2")) {
+      if (is.null(probs)) {
+        sprintf(
+          "For `variance_estimator='%s'`, must supply a matrix or data frame to `probs`.",
+          variance_estimator
+        ) |> stop()
+      }
+    }
+
     if (variance_estimator == "Stratified Multistage SRS") {
       if (is.null(strata_pop_sizes)) {
         stop("For `variance_estimator='Stratified Multistage SRS'`, must supply a matrix or data frame to `strata_pop_sizes`.")
       }
     }
-    if (variance_estimator %in% c("SD1", "SD2")) {
+    if (variance_estimator %in% c("SD1", "SD2", "Deville-1", "Deville-2")) {
       if (is.null(cluster_ids)) {
         sprintf(
           "For `variance_estimator='%s'`, must supply a matrix or data frame to `cluster_ids`",
           variance_estimator
         ) |> stop()
       }
+    }
+    if (variance_estimator %in% c("SD1", "SD2")) {
       if (is.null(sort_order)) {
         sprintf(
           "For `variance_estimator='%s'`, must supply a vector to `sort_order`",
@@ -303,6 +385,7 @@ make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
       }
     }
 
+
     if (is.null(strata_pop_sizes)) {
       strata_pop_sizes <- matrix(data = Inf,
                                  nrow = number_of_ultimate_units,
@@ -353,7 +436,7 @@ make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
     }
   }
 
-  if (variance_estimator == "Stratified Multistage SRS") {
+  if (variance_estimator %in% c("Stratified Multistage SRS", "Deville-1", "Deville-2")) {
     quad_form_matrix <- matrix(data = 0,
                                nrow = number_of_ultimate_units,
                                ncol = number_of_ultimate_units)
@@ -368,30 +451,64 @@ make_quad_form_matrix <- function(variance_estimator = "Yates-Grundy",
     while (stage <= number_of_stages) {
       # Generate quadratic form for each stratum
       for (stratum_id in unique(strata_ids[,stage,drop=TRUE])) {
-        # Variance of estimated total from current stage units
+
         stratum_indices <- which(strata_ids[,stage,drop=TRUE] == stratum_id)
-        stratum_pop_size <- strata_pop_sizes[,stage,drop=TRUE][stratum_indices[1]]
-        n_clusters <- sampsize[,stage,drop=TRUE][stratum_indices[1]]
 
-        Q_current <- distribute_matrix_across_clusters(
-          cluster_level_matrix = make_srswor_matrix(n = n_clusters,
-                                                    f = (n_clusters/stratum_pop_size)),
-          cluster_ids = cluster_ids[stratum_indices, stage, drop = TRUE],
-          rows = TRUE, cols = TRUE
-        )
+        if (variance_estimator == "Stratified Multistage SRS") {
+
+          # Get quadratic form at current stage
+          stratum_pop_size <- strata_pop_sizes[,stage,drop=TRUE][stratum_indices[1]]
+          n_clusters <- sampsize[,stage,drop=TRUE][stratum_indices[1]]
+
+          Q_current <- distribute_matrix_across_clusters(
+            cluster_level_matrix = make_srswor_matrix(n = n_clusters,
+                                                      f = (n_clusters/stratum_pop_size)),
+            cluster_ids = cluster_ids[stratum_indices, stage, drop = TRUE],
+            rows = TRUE, cols = TRUE
+          )
+          # Get product of sampling probabilities from previous stages
+          if (stage > 1) {
+            prev_n_clusters <- sampsize[stratum_indices[1],seq_len(stage-1),drop=TRUE]
+            prev_stratum_pop_size <- strata_pop_sizes[stratum_indices[1],seq_len(stage-1),drop=TRUE]
+            prev_samp_fraction <- (
+              Reduce(f = `*`, x = prev_n_clusters) / Reduce(f = `*`, x = prev_stratum_pop_size)
+            )
+          } else {
+            prev_samp_fraction <- 1
+          }
+          prev_stages_samp_prob <- prev_samp_fraction
+        }
+
+        if (variance_estimator %in% c("Deville-1", "Deville-2")) {
+
+          # Get quadratic form at current stage
+          current_cluster_ids <- cluster_ids[stratum_indices, stage, drop = TRUE]
+          current_probs <- probs[stratum_indices, stage, drop = TRUE]
+          cluster_probs <- current_probs[!duplicated(current_cluster_ids)]
+
+          Q_current <- distribute_matrix_across_clusters(
+            cluster_level_matrix = make_ppswor_approx_matrix(
+              probs = cluster_probs,
+              method = variance_estimator
+            ),
+            cluster_ids = cluster_ids[stratum_indices, stage, drop = TRUE],
+            rows = TRUE, cols = TRUE
+          )
+          # Get product of sampling probabilities from previous stages
+          if (stage > 1) {
+            probs_at_prev_stages <- probs[stratum_indices[1],seq_len(stage-1),drop=TRUE]
+            prev_stages_samp_prob <- Reduce(f = `*`, x = probs_at_prev_stages)
+          } else {
+            prev_stages_samp_prob <- 1
+          }
 
-        # Obtain product of previous-stage sampling fractions
-        if (stage > 1) {
-          prev_n_clusters <- sampsize[stratum_indices[1],seq_len(stage-1),drop=TRUE]
-          prev_stratum_pop_size <- strata_pop_sizes[stratum_indices[1],seq_len(stage-1),drop=TRUE]
-          prev_samp_fraction <- Reduce(f = `*`, x = prev_n_clusters)/Reduce(f = `*`, x = prev_stratum_pop_size)
-        } else {
-          prev_samp_fraction <- 1
         }
 
         # Add overall variance contribution from current stage/stratum sampling
-        quad_form_matrix[stratum_indices,stratum_indices] <- quad_form_matrix[stratum_indices,stratum_indices] +
-          (Q_current * prev_samp_fraction)
+        quad_form_matrix[stratum_indices,stratum_indices] <- (
+          quad_form_matrix[stratum_indices,stratum_indices] +
+            (Q_current * prev_stages_samp_prob)
+        )
 
       }
       stage <- stage + 1L
@@ -556,6 +673,88 @@ make_srswor_matrix <- function(n, f = 0) {
   return(C_matrix)
 }
 
+#' @title Create a quadratic form's matrix to represent a variance estimator
+#' for PPSWOR designs, based on commonly-used approximations
+#' @description Several variance estimators for designs that use
+#' unequal probability sampling without replacement (i.e., PPSWOR),
+#' variance estimation tends to be more accurate
+#' when using an approximation estimator that uses the first-order
+#' inclusion probabilities (i.e., the basic sampling weights)
+#' and ignores the joint inclusion probabilities.
+#' This function returns the matrix of the quadratic form used
+#' to represent such variance estimators.
+#' @param probs A vector of first-order inclusion probabilities
+#' @param method A string specifying the approximation method to use.
+#' See the "Details" section below.
+#' Options include:
+#' \itemize{
+#'   \item{"Deville-1"}
+#'   \item{"Deville-2"}
+#' }
+
+#' @return A symmetric matrix whose dimension matches the length of \code{probs}.
+#' @details
+#' These variance estimators have been shown to be effective
+#' for designs that use a fixed sample size with a high-entropy sampling method.
+#' This includes most PPSWOR sampling methods,
+#' but unequal-probability systematic sampling is an important exception.
+#'
+#' These variance estimators generally take the following form:
+#' \deqn{
+#' \hat{v}(\hat{Y}) = \sum_{i=1}^{n} c_i (\breve{y}_i - \frac{1}{\sum_{i=k}^{n}c_k}\sum_{k=1}^{n}c_k \breve{y}_k)^2
+#' }
+#' where \eqn{\breve{y}_i = y_i/\pi_i} is the weighted value of the the variable of interest,
+#' and \eqn{c_i} are constants that depend on the approximation method used.  \cr \cr
+#' The matrix of the quadratic form, denoted \eqn{\Sigma}, has
+#' its \eqn{ij}-th entry defined as follows:
+#' \deqn{
+#'   \sigma_{ii} = c_i (1 - \frac{c_i}{\sum_{k=1}^{n}c_k}) \textit{ when } i = j \\
+#'   \sigma_{ij}=\frac{-c_i c_j}{\sum_{k=1}^{n}c_k} \textit{ when } i \neq j \\
+#' }
+#' The constants \eqn{c_i} are defined for each approximation method as follows,
+#' with the names taken directly from Matei and Tillé (2005).
+#' \itemize{
+#'   \item{\strong{"Deville-1"}: }{
+#'     \deqn{c_i=\left(1-\pi_i\right) \frac{n}{n-1}}}
+#'   \item{\strong{"Deville-2"}: }{
+#'     \deqn{c_i = (1-\pi_i) \left[1 - \sum_{k=1}^{n} \left(\frac{1-\pi_k}{\sum_{k=1}^{n}(1-\pi_k)}\right)^2 \right]^{-1}}}
+#' }
+#' Both of the approximations \strong{"Deville-1"} and \strong{"Deville-2"} were shown
+#' in the simulation studies of Matei and Tillé (2005) to perform much better
+#' in terms of MSE compared to the strictly-unbiased
+#' Horvitz-Thompson and Yates-Grundy variance estimators.
+#' In the case of simple random sampling without replacement (SRSWOR),
+#' these estimators are identical to the usual Horvitz-Thompson variance estimator.
+#'
+#' @references
+#' Matei, Alina, and Yves Tillé. 2005.
+#' “Evaluation of Variance Approximations and Estimators
+#' in Maximum Entropy Sampling with Unequal Probability and Fixed Sample Size.”
+#' Journal of Official Statistics 21(4):543–70.
+#'
+#' @keywords internal
+make_ppswor_approx_matrix <- function(probs, method = "Deville-1") {
+
+  one_minus_pi <- 1 - probs
+
+  if (method == "Deville-1") {
+    n <- length(probs)
+    c_k <- (1 - probs) * (n/(n-1))
+  }
+  if (method == "Deville-2") {
+    c_k <- (1 - probs) / (
+      1 - sum( (one_minus_pi/sum(one_minus_pi))^2 )
+    )
+  }
+
+  c_sum <- sum(c_k)
+
+  Sigma <- outer(c_k, -c_k) / c_sum
+  diag(Sigma) <- c_k*(1 - c_k/c_sum)
+
+  return(Sigma)
+}
+
 #' @title Helper function to turn a cluster-level matrix into an element-level matrix
 #' by duplicating rows or columns of the matrix
 #' @description Turns a cluster-level matrix into an element-level matrix
@@ -780,7 +979,7 @@ ht_matrix_to_joint_probs <- function(ht_quad_form) {
 #'   where \eqn{\pi_{bk}} is the conditional probability that unit \eqn{k}
 #'   is included in the second-phase sample, given the selected first-phase sample.
 #' }
-#' @section Ensuring the Result is Positive semidefinite:
+#' @section Ensuring the Result is Positive Semidefinite:
 #' Note that the matrix \eqn{(\boldsymbol{\Sigma}_{a^\prime} \circ D_b )} may not be
 #' positive semidefinite, since the matrix \eqn{D_b} is not guaranteed to be positive semidefinite.
 #' If \eqn{(\boldsymbol{\Sigma}_{a^\prime} \circ D_b )} is found not to be positive semidefinite,
